#PBS -l nodes=8:ppn=8
#PBS -l walltime=8:0:0
#PBS -m ae
#PBS -o stdout.log
#PBS -e stderr.log

from ase.io import read
from ase.lattice.surface import fcc111, add_adsorbate
from gpaw import GPAW, Mixer
from gpaw.utilities import h2gpts

system = read('geom.traj')
system.numbers[:-1] = 47
system.positions[-1, 2] = system.positions[:-1, 2].max()
system.positions *= 4.166 / 4.218
system.positions[-1, 2] += 1.37
system.center(vacuum=5.5, axis=2)

calc = GPAW(xc='RPBE',
            gpts=h2gpts(0.175454, system.get_cell(), idiv=8),
            txt='gpaw.full.txt',
            kpts=(4, 4, 1),
            nbands=int(len(system) * 5.9),
            mixer=Mixer(0.1, 5, 50.0),
            maxiter=120,
            )

system.set_calculator(calc)
system.get_potential_energy()

system.pop(-1)
calc.set(txt='gpaw.clean.txt')
system.get_potential_energy()
