#PBS -l nodes=4:ppn=8
#PBS -l walltime=13:0:0
#PBS -m ae
#PBS -o stdout.log
#PBS -e stderr.log

from ase.io import read
from ase.lattice.surface import fcc111, add_adsorbate
from gpaw import GPAW, Mixer
from gpaw.utilities import h2gpts

system = read('geom.traj')
system.center(vacuum=5.5, axis=2)

calc = GPAW(xc='RPBE',
            mode='lcao',
            basis='dzp',
            gpts=h2gpts(0.175454, system.get_cell(), idiv=8),
            txt='gpaw.full.txt',
            kpts=(2, 2, 1),
            parallel=dict(sl_default=(4, 4, 64)),
            nbands=len(system) * 6,
            mixer=Mixer(0.1, 5, 50.0),
            )

system.set_calculator(calc)
system.get_potential_energy()

system.pop(-1)
calc.set(txt='gpaw.clean.txt')
system.get_potential_energy()
