#PBS -l nodes=6:ppn=8
#PBS -l walltime=6:0:0
#PBS -m ae
#PBS -e stderr.log
#PBS -o stdout.log

from ase.visualize import view
from ase.constraints import FixAtoms
from ase.optimize import QuasiNewton
from ase import Atoms, Atom
import numpy as np
from gpaw import Mixer
from math import sqrt
test=0
import os
from math import ceil
a0 = 4.218
grid_spacing = a0 / 24

try:
    geomdata = map(int, open('O.dat').read().split())
    assert len(geomdata) == 4
except (IOError, ValueError):
    geomdata = None


def surf_211(mat, a0):
    cell=[(a0*sqrt(3.), 0, 0),
          (0, sqrt(2.)*a0, 0),
          (0, 0, 4.89897947*a0)]

    system=Atoms([Atom(mat, (0, 0, 0),tag=1),
                  Atom(mat, (0, 0.5, 0),tag=1),
                  Atom(mat, (0.3333, 0.25, -0.0416667),tag=1),
                  Atom(mat, (0.3333, 0.75, -0.0416667),tag=1),
                  Atom(mat, (0.66667, 0, -0.083333),tag=1),
                  Atom(mat, (0.66667, 0.5, -0.083333),tag=1),
                  Atom(mat, (0.00000000 ,    0.25000000,-0.12500000 )),
                  Atom(mat, (0.00000000 ,    0.75000000 ,-0.12500000)),
                  Atom(mat, (0.33333333 ,    0.00000000 ,-0.16666667)),
                  Atom(mat, (0.33333333 ,    0.50000000 ,-0.16666667)),
                  Atom(mat, (0.66666667 ,    0.25000000 ,-0.20833333)),
                  Atom(mat, (0.66666667 ,    0.75000000 ,-0.20833333)),
                 ])
    system.set_cell(cell, scale_atoms=True)
    D = a0 / 2.**.5
    X = np.vdot(system.positions[0] - system.positions[6], [0.,0.,1.])
    system.positions[:, 2] *= -1.0
    system.cell[2, 2] = 2.0 * X
    system = system.repeat((1, 1, 2))
    system.positions[:, 2] *= -1.0

    system.set_pbc((1, 1, 0))
    c=system.cell
    c[2][2]= 25.0
    c[2][2]=ceil(c[2][2] / grid_spacing) * grid_spacing
    system.set_cell(c)
    system.center()
    if geomdata is not None:
        neighb = geomdata[:3]
        backg = geomdata[3]

        cen = system.positions[neighb].sum(axis=0) / 3
        normal = cen - system.positions[backg]
        normal /= np.linalg.norm(normal)

        system += Atoms('O', positions=[cen + normal * 1.37])
    return(system)

from ase.lattice.surface import fcc111
mols={'CO_top' : [['C',2.0], ['O',3.15]],
      'CO' : [['C', 1.47], ['O',1.47+1.15]],
      'O_top' :[['O',1.9]],
      'O' :[['O',1.37]],
      'clean' : []}
    
def xxx(atoms, type):
    if test: return(EMT())
    from gpaw import GPAW
    nbands = len(atoms)*6 + 8
    calc = GPAW(nbands=nbands,
                xc='RPBE',
                h=grid_spacing, #   Grid spacing
                kpts=[6, 6, 1],
                txt='gpaw.txt',
                usesymm=True,
                mixer=Mixer(0.1, 5, 50.0),
                width=0.1
                )
    return(calc)

ads = 'O'
i = '211_top'
    
c_ads = ads
fsurf, fpos = i.split('_')
if fpos != 'clean':
    fpos += '_'+ads
filename = fsurf +'_' + fpos
#if 'clean' in i:
#    c_ads = 'clean'
    #if '111' in i:
    #  atoms = fcc111('Pt', (2, 2, 4), orthogonal=True, a=a0, vacuum=13.0)
    #  c=atoms.cell
    #  c[2][2]=ceil(c[2][2] / grid_spacing) * grid_spacing
    #  atoms.set_cell(c)
    
    #  calc=xxx(atoms, '111')
    #  if 'top' in i:
    #      ref_pos=[12]
    #      c_ads = ads + '_top'
    #  if 'fcc' in i:
    #     ref_pos =[12,13,14]
    #  if 'hcp' in i:         
    #     ref_pos =[13,14,15]
atoms = surf_211('Au', a0)
    #if 'top' in i:
    #     c_ads = c_ads + '_top'
    # ref_pos=[0]
calc=xxx(atoms, '211')
    #mol = mols[c_ads]
    #cp=np.array([0.0,0.0,0.0])
    #for rp in ref_pos:
    #    cp += atoms[rp].position
    #cp /= len(ref_pos)     
    #for m in mol:
    #   atoms.append(Atom(m[0], cp+[0.0, 0.0, m[1]])) 
    #if not test: calc.set(txt=filename + '.txt')    
atoms.set_calculator(calc)
atoms.get_potential_energy()
