#PBS -l nodes=16:ppn=4:opteron
#PBS -l walltime=13:0:0
#PBS -m ae
#PBS -o stdout.log
#PBS -e stderr.log

from ase.io import read
from ase.lattice.surface import fcc111, add_adsorbate
from gpaw import GPAW, Mixer
from gpaw.utilities import h2gpts

system = read('geom.traj')
system.numbers[:-1] = 46
system.positions[-1, 2] -= 1.37
system.positions *= 3.952 / 4.218
system.positions[-1, 2] += 1.2867
system.center(vacuum=5.5, axis=2)

calc = GPAW(xc='RPBE',
            gpts=h2gpts(0.175454, system.get_cell(), idiv=8),
            txt='gpaw.full.txt',
            kpts=(4, 4, 1),
            nbands=int(len(system) * 5.65),
            mixer=Mixer(0.03, 7, 100.0),
            maxiter=180,
            )

system.set_calculator(calc)
system.get_potential_energy()

system.pop(-1)
calc.set(txt='gpaw.clean.txt')
system.get_potential_energy()
