#PBS -l nodes=4:ppn=8
#PBS -l walltime=13:0:0
#PBS -m ae
#PBS -o stdout.log
#PBS -e stderr.log

from ase.io import read
from ase.lattice.surface import fcc111, add_adsorbate
from gpaw import GPAW, Mixer
from gpaw.utilities import h2gpts

system = fcc111('Pt', a=3.999, size=(2, 2, 10), orthogonal=True)
add_adsorbate(system, 'O', 1.37, 'fcc')
#system = read('geom.traj')
system.center(vacuum=5.5, axis=2)

calc = GPAW(xc='RPBE',
            gpts=h2gpts(0.175454, system.get_cell(), idiv=8),
            txt='gpaw.full.txt',
            kpts=(4, 4, 1),
            nbands=len(system) * 6,
            mixer=Mixer(0.03, 7, 100.0),
            )

system.set_calculator(calc)
system.get_potential_energy()

system.pop(-1)
calc.set(txt='gpaw.clean.txt')
system.get_potential_energy()
