import os
#from glob import glob
from ase.io import read
import pylab as pl
import numpy as np
from get_coordination import get_coordination

def s2a(s):
    return np.array(map(float, s.split()))

Au_O_clusters = s2a("""
-3.4100
-2.0240
-2.6930
-2.5240
-2.3360
-2.2980
-2.3430""")

Pt_O_clusters = s2a("""-4.7434
-3.6929
-3.4698
-3.4883
-3.4115
-3.4013
-3.4476""")

cluster_C = s2a("""5.0000
7.0000
7.6667
8.3333
9.0000
9.0000
9.0000""")


def main(basedir='.'):
    moredirs = 'banded l6 p3 p4 p5 p6 shifted xbanded'.split()

    cvalues = []
    evalues = []

    def append(c, e):
        cvalues.append(C)
        evalues.append(E)
    
    ref = '%s/211surf/211_clean/gpaw.txt' % basedir

    Eref = read(ref).get_potential_energy()
    Oref = -2.08

    fnames1 = ['211surf/211_Ofcc1/gpaw.txt',
               '211surf/211_Ofcc2/gpaw.txt',
               '211surf/211_Ohcp/gpaw.txt']

    Z = set()
    def nonsense(system):
        if len(Z) == 0:
            Z.add(system.numbers[0])
            return False
        else:
            return not system.numbers[0] in Z
    for fname in fnames1:
        system = read('%s/%s' % (basedir, fname))
        if nonsense(system):
            continue
        r = list(get_coordination(system))
        assert len(r) == 1
        nn = r[0][-2]
        nncn = r[0][-1]
        C = (sum(nn) + 2 * sum(nncn)) / float(len(nn))
        #print C
        #C = float(sum(nn)) / len(nn)
        print C
        E = system.get_potential_energy() - Eref - Oref
        append(C, E)
        pl.plot([C], [E], 'ms')

    #moredirs = glob('moreplateaus/{banded,l6,p3,p4,p5,p6,shifted,xbanded}')
    for dirname in moredirs:
        style = 'gs'
        if dirname == 'l6':
            style = 'ks'
        elif dirname.startswith('p') and len(dirname) == 2:
            style = 'bs'
        S1 = read('%s/moreplateaus/%s/gpaw.clean.txt' % (basedir, dirname))
        S2 = read('%s/moreplateaus/%s/gpaw.full.txt' % (basedir, dirname))
        if nonsense(S1) or nonsense(S2):
            continue
        #assert S1.get_chemical_symbols() + ['O'] == S2.get_chemical_symbols()
        print S1
        print S2
        #try:
        E1 = S1.get_potential_energy()
        E2 = S2.get_potential_energy()
        #except RuntimeError:
        #    continue
        r = list(get_coordination(S2))
        nn = r[0][-2]
        nncn = r[0][-1]
        #C = float(sum(nn)) / len(nn)
        C = (sum(nn) + 2 * sum(nncn)) / float(len(nn))
        E = E2 - E1 - Oref
        append(C, E)
        print C, E
        pl.plot([C], [E], style)
        sym = S1.get_chemical_symbols()[0]
    from scipy import polyfit, polyval
    P = polyfit(cvalues, evalues, 1)
    X = [4.6, 10.0]
    Y = polyval(P, X)
    pl.plot(X, Y, 'k--', lw=2)
    return sym

if __name__ == '__main__':
    #import sys
    #args = sys.argv[1:]
    #if len(args) == 0:
    #    main()
    #else:
    #    nargs = len(args)
    args = 'Au Pt'.split()
    nargs = len(args)
    for i, arg in enumerate(args):
        pl.subplot(nargs, 1, 1 + i)
        sym = main(arg)

        if arg == 'Au':
            pl.plot(cluster_C, Au_O_clusters, 'ro')
        elif arg == 'Pt':
            pl.plot(cluster_C, Pt_O_clusters, 'ro')
        pl.ylabel('%s Eads / eV' % sym)
        #pl.axis(xmin=4.7, xmax=10)

        
    pl.xlabel('Avg coordination')
    pl.show()

#os.system('get_coordination.py 211surf/*/*.txt > coordinations211.txt')
#open('coordinations211.txt')
#import pylab as pl
